@@ -43,11 +43,11 @@
 #' NULL` would only return the HDI (or CI).
 #'
 #' @references
-#' \itemize{
-#'   \item Makowski, D., Ben-Shachar, M. S., Chen, S. H. A., \& Lüdecke, D. (2019). *Indices of Effect Existence and Significance in the Bayesian Framework*. Frontiers in Psychology 2019;10:2767. \doi{10.3389/fpsyg.2019.02767}
-#'   \item [Region of Practical Equivalence (ROPE)](https://easystats.github.io/bayestestR/articles/region_of_practical_equivalence.html)
-#'   \item [Bayes factors](https://easystats.github.io/bayestestR/articles/bayes_factors.html)
-#' }
+#' - Makowski, D., Ben-Shachar, M. S., Chen, S. H. A., and Lüdecke, D. (2019).
+#'   *Indices of Effect Existence and Significance in the Bayesian Framework*.
+#'   Frontiers in Psychology 2019;10:2767. \doi{10.3389/fpsyg.2019.02767}
+#' - [Region of Practical Equivalence (ROPE)](https://easystats.github.io/bayestestR/articles/region_of_practical_equivalence.html)
+#' - [Bayes factors](https://easystats.github.io/bayestestR/articles/bayes_factors.html)
 #'
 #' @examples
 #' library(bayestestR)
@@ -106,7 +106,9 @@ describe_posterior <- function(posteriors, ...) {
 
 #' @export
 describe_posterior.default <- function(posteriors, ...) {
-  stop(insight::format_message(paste0("'describe_posterior()' is not yet implemented for objects of class '", class(posteriors)[1], "'.")), call. = FALSE)
+  stop(insight::format_message(
+    paste0("`describe_posterior()` is not yet implemented for objects of class `", class(posteriors)[1], "`.")
+  ), call. = FALSE)
 }
 
 
@@ -129,6 +131,16 @@ describe_posterior.default <- function(posteriors, ...) {
   }
 
 
+  if (!is.data.frame(x) && !is.numeric(x)) {
+    is_stanmvreg <- inherits(x, "stanmvreg")
+    cleaned_parameters <- insight::clean_parameters(x)
+    # rename to use `x` in bayes factor later
+    x_df <- insight::get_parameters(x, ...)
+  } else {
+    cleaned_parameters <- NULL
+    x_df <- x
+  }
+
   # Arguments fixes
   if (!is.null(centrality) && length(centrality) == 1 && (centrality == "none" || centrality == FALSE)) centrality <- NULL
   if (!is.null(ci) && length(ci) == 1 && (is.na(ci) || ci == FALSE)) ci <- NULL
@@ -138,7 +150,11 @@ describe_posterior.default <- function(posteriors, ...) {
   # Point-estimates
 
   if (!is.null(centrality)) {
-    estimates <- point_estimate(x, centrality = centrality, dispersion = dispersion, ...)
+    estimates <- .prepare_output(
+      point_estimate(x_df, centrality = centrality, dispersion = dispersion, ...),
+      cleaned_parameters,
+      is_stanmvreg
+    )
     if (!"Parameter" %in% names(estimates)) {
       estimates <- cbind(data.frame("Parameter" = "Posterior"), estimates)
     }
@@ -151,11 +167,17 @@ describe_posterior.default <- function(posteriors, ...) {
 
   if (!is.null(ci)) {
     ci_method <- match.arg(tolower(ci_method), c("hdi", "spi", "quantile", "ci", "eti", "si", "bci", "bcai"))
+    # not sure why "si" requires the model object
     if (ci_method == "si") {
       uncertainty <- ci(x, BF = BF, method = ci_method, prior = bf_prior, ...)
     } else {
-      uncertainty <- ci(x, ci = ci, method = ci_method, ...)
+      uncertainty <- ci(x_df, ci = ci, method = ci_method, ...)
     }
+    uncertainty <- .prepare_output(
+      uncertainty,
+      cleaned_parameters,
+      is_stanmvreg
+    )
 
     if (!"Parameter" %in% names(uncertainty)) {
       uncertainty <- cbind(data.frame("Parameter" = "Posterior"), uncertainty)
@@ -174,22 +196,28 @@ describe_posterior.default <- function(posteriors, ...) {
     }
 
     ## TODO no BF for arm::sim
-    if (inherits(x, c("sim", "sim.merMod", "mcmc", "stanfit"))) {
+    if (inherits(x_df, c("sim", "sim.merMod", "mcmc", "stanfit"))) {
       test <- setdiff(test, "bf")
     }
 
     ## TODO enable once "rope()" works for multi-response models
 
     # no ROPE for multi-response models
-    if (insight::is_multivariate(x)) {
+    if (insight::is_multivariate(x_df)) {
       test <- setdiff(test, c("rope", "p_rope"))
-      warning(insight::format_message("Multivariate response models are not yet supported for tests 'rope' and 'p_rope'."), call. = FALSE)
+      warning(insight::format_message(
+        "Multivariate response models are not yet supported for tests `rope` and `p_rope`."
+      ), call. = FALSE)
     }
 
     # MAP-based p-value
 
     if (any(c("p_map", "p_pointnull") %in% test)) {
-      test_pmap <- p_map(x, ...)
+      test_pmap <- .prepare_output(
+        p_map(x_df, ...),
+        cleaned_parameters,
+        is_stanmvreg
+      )
       if (!is.data.frame(test_pmap)) test_pmap <- data.frame("Parameter" = "Posterior", "p_map" = test_pmap)
     } else {
       test_pmap <- data.frame("Parameter" = NA)
@@ -199,7 +227,11 @@ describe_posterior.default <- function(posteriors, ...) {
     # Probability of direction
 
     if (any(c("pd", "p_direction", "pdir", "mpe") %in% test)) {
-      test_pd <- p_direction(x, ...)
+      test_pd <- .prepare_output(
+        p_direction(x_df, ...),
+        cleaned_parameters,
+        is_stanmvreg
+      )
       if (!is.data.frame(test_pd)) test_pd <- data.frame("Parameter" = "Posterior", "pd" = test_pd)
     } else {
       test_pd <- data.frame("Parameter" = NA)
@@ -208,7 +240,11 @@ describe_posterior.default <- function(posteriors, ...) {
     # Probability of rope
 
     if (any(c("p_rope") %in% test)) {
-      test_prope <- p_rope(x, range = rope_range, ...)
+      test_prope <- .prepare_output(
+        p_rope(x_df, range = rope_range, ...),
+        cleaned_parameters,
+        is_stanmvreg
+      )
       if (!"Parameter" %in% names(test_prope)) {
         test_prope <- cbind(data.frame("Parameter" = "Posterior"), test_prope)
       }
@@ -219,7 +255,11 @@ describe_posterior.default <- function(posteriors, ...) {
     # Probability of significance
 
     if (any(c("ps", "p_sig", "p_significance") %in% test)) {
-      test_psig <- p_significance(x, threshold = rope_range, ...)
+      test_psig <- .prepare_output(
+        p_significance(x_df, threshold = rope_range, ...),
+        cleaned_parameters,
+        is_stanmvreg
+      )
       if (!is.data.frame(test_psig)) test_psig <- data.frame("Parameter" = "Posterior", "ps" = test_psig)
     } else {
       test_psig <- data.frame("Parameter" = NA)
@@ -229,8 +269,11 @@ describe_posterior.default <- function(posteriors, ...) {
     # ROPE
 
     if (any(c("rope") %in% test)) {
-      test_rope <- rope(x, range = rope_range, ci = rope_ci, ...)
-
+      test_rope <- .prepare_output(
+        rope(x_df, range = rope_range, ci = rope_ci, ...),
+        cleaned_parameters,
+        is_stanmvreg
+      )
       if (!"Parameter" %in% names(test_rope)) {
         test_rope <- cbind(data.frame("Parameter" = "Posterior"), test_rope)
       }
@@ -249,11 +292,15 @@ describe_posterior.default <- function(posteriors, ...) {
         equi_warnings <- TRUE
       }
 
-      test_equi <- equivalence_test(x,
-        range = rope_range,
-        ci = rope_ci,
-        verbose = equi_warnings,
-        ...
+      test_equi <- .prepare_output(
+        equivalence_test(x_df,
+          range = rope_range,
+          ci = rope_ci,
+          verbose = equi_warnings,
+          ...
+        ),
+        cleaned_parameters,
+        is_stanmvreg
       )
       test_equi$Cleaned_Parameter <- NULL
 
@@ -270,7 +317,14 @@ describe_posterior.default <- function(posteriors, ...) {
     # Bayes Factors
 
     if (any(c("bf", "bayesfactor", "bayes_factor") %in% test)) {
-      test_bf <- bayesfactor_parameters(x, prior = bf_prior, ...)
+      test_bf <- tryCatch(
+        .prepare_output(
+          bayesfactor_parameters(x, prior = bf_prior, ...),
+          cleaned_parameters,
+          is_stanmvreg
+        ),
+        error = function(e) data.frame("Parameter" = NA)
+      )
       if (!"Parameter" %in% names(test_bf)) {
         test_bf <- cbind(data.frame("Parameter" = "Posterior"), test_bf)
       }
@@ -341,21 +395,21 @@ describe_posterior.default <- function(posteriors, ...) {
   # row-order after merging
 
   if (!all(is.na(estimates$Parameter))) {
-    estimates$.rowid <- 1:nrow(estimates)
+    estimates$.rowid <- seq_len(nrow(estimates))
   } else if (!all(is.na(test_pmap$Parameter))) {
-    test_pmap$.rowid <- 1:nrow(test_pmap)
+    test_pmap$.rowid <- seq_len(nrow(test_pmap))
   } else if (!all(is.na(test_pd$Parameter))) {
-    test_pd$.rowid <- 1:nrow(test_pd)
+    test_pd$.rowid <- seq_len(nrow(test_pd))
   } else if (!all(is.na(test_prope$Parameter))) {
-    test_prope$.rowid <- 1:nrow(test_prope)
+    test_prope$.rowid <- seq_len(nrow(test_prope))
   } else if (!all(is.na(test_psig$Parameter))) {
-    test_psig$.rowid <- 1:nrow(test_psig)
+    test_psig$.rowid <- seq_len(nrow(test_psig))
   } else if (!all(is.na(test_rope$Parameter))) {
-    test_rope$.rowid <- 1:nrow(test_rope)
+    test_rope$.rowid <- seq_len(nrow(test_rope))
   } else if (!all(is.na(test_bf$Parameter))) {
-    test_bf$.rowid <- 1:nrow(test_bf)
+    test_bf$.rowid <- seq_len(nrow(test_bf))
   } else {
-    estimates$.rowid <- 1:nrow(estimates)
+    estimates$.rowid <- seq_len(nrow(estimates))
   }
 
 
@@ -368,7 +422,6 @@ describe_posterior.default <- function(posteriors, ...) {
   # merge all data frames
   merge_by <- c("Parameter", "Effects", "Component", "Response")
   # merge_by <- intersect(merge_by, colnames(estimates))
-
   out <- merge(estimates, uncertainty, by = merge_by, all = TRUE)
   out <- merge(out, test_pmap, by = merge_by, all = TRUE)
   out <- merge(out, test_pd, by = merge_by, all = TRUE)
@@ -378,7 +431,6 @@ describe_posterior.default <- function(posteriors, ...) {
   out <- merge(out, test_bf, by = merge_by, all = TRUE)
   out <- out[!is.na(out$Parameter), ]
 
-
   # check which columns can be removed at the end. In any case, we don't
   # need .rowid in the returned data frame, and when the Effects or Component
   # column consist only of missing values, we remove those columns as well
@@ -394,12 +446,8 @@ describe_posterior.default <- function(posteriors, ...) {
   # Add iterations
   if (keep_iterations == TRUE) {
     row_order <- out$Parameter
-    if (insight::is_model(x)) {
-      iter <- as.data.frame(t(insight::get_parameters(x, ...)))
-    } else {
-      iter <- as.data.frame(t(as.data.frame(x, ...)))
-    }
-    names(iter) <- paste0("iter_", 1:ncol(iter))
+    iter <- as.data.frame(t(as.data.frame(x_df, ...)))
+    names(iter) <- paste0("iter_", seq_len(ncol(iter)))
     iter$Parameter <- row.names(iter)
     out <- merge(out, iter, all.x = TRUE, by = "Parameter")
     out <- out[match(row_order, out$Parameter), ]
@@ -560,6 +608,8 @@ describe_posterior.draws <- function(posteriors,
   out
 }
 
+#' @export
+describe_posterior.rvar <- describe_posterior.draws
 
 
 
@@ -649,7 +699,7 @@ describe_posterior.get_predicted <- function(posteriors,
       ...
     )
   } else {
-    stop("No iterations present in the output.")
+    stop("No iterations present in the output.", call. = FALSE)
   }
 }
 
@@ -737,8 +787,9 @@ describe_posterior.stanreg <- function(posteriors,
                                        parameters = NULL,
                                        BF = 1,
                                        ...) {
-  if ((any(c("all", "bf", "bayesfactor", "bayes_factor") %in% tolower(test)) | "si" %in% tolower(ci_method)) & is.null(bf_prior)) {
-    bf_prior <- unupdate(posteriors)
+  if ((any(c("all", "bf", "bayesfactor", "bayes_factor") %in% tolower(test)) ||
+    "si" %in% tolower(ci_method)) && is.null(bf_prior)) {
+    bf_prior <- suppressMessages(unupdate(posteriors))
   }
 
   effects <- match.arg(effects)
@@ -926,8 +977,9 @@ describe_posterior.brmsfit <- function(posteriors,
   effects <- match.arg(effects)
   component <- match.arg(component)
 
-  if ((any(c("all", "bf", "bayesfactor", "bayes_factor") %in% tolower(test)) | "si" %in% tolower(ci_method)) & is.null(bf_prior)) {
-    bf_prior <- unupdate(posteriors)
+  if ((any(c("all", "bf", "bayesfactor", "bayes_factor") %in% tolower(test)) ||
+    "si" %in% tolower(ci_method)) && is.null(bf_prior)) {
+    bf_prior <- suppressMessages(unupdate(posteriors))
   }
 
   out <- .describe_posterior(
@@ -1113,7 +1165,6 @@ describe_posterior.BFBayesFactor <- function(posteriors,
                                              priors = TRUE,
                                              verbose = TRUE,
                                              ...) {
-
   # Match test args  to catch BFs
   if (!is.null(test)) {
     test <- .check_test_values(test)
