@@ -4,6 +4,7 @@
 #'
 #' @param model A Bayesian model.
 #' @param ... Currently not used.
+#' @inheritParams describe_posterior
 #'
 #' @examples
 #' \dontrun{
@@ -36,7 +37,7 @@ describe_prior <- function(model, ...) {
 }
 
 
-
+#' @rdname describe_prior
 #' @export
 describe_prior.brmsfit <- function(model,
                                    effects = c("fixed", "random", "all"),
@@ -90,35 +91,16 @@ describe_prior.brmsfit <- function(model,
   priors
 }
 
-
 #' @export
 describe_prior.stanreg <- .describe_prior
 
 
-
 #' @export
 describe_prior.bcplm <- .describe_prior
 
 #' @export
 describe_prior.blavaan <- .describe_prior
 
-#' @export
-describe_prior.mcmc.list <- function(model, ...) {
-  NULL
-}
-
-#' @export
-describe_prior.BGGM <- function(model, ...) {
-  NULL
-}
-
-#' @export
-describe_prior.bamlss <- function(model, ...) {
-  NULL
-}
-
-
-
 #' @export
 describe_prior.BFBayesFactor <- function(model, ...) {
   priors <- insight::get_priors(model)
@@ -128,3 +110,23 @@ describe_prior.BFBayesFactor <- function(model, ...) {
 
   priors
 }
+
+
+# unsupported ----------------
+
+#' @export
+describe_prior.BGGM <- function(model, ...) {
+  NULL
+}
+
+#' @export
+describe_prior.BGGM <- describe_prior.BGGM
+
+#' @export
+describe_prior.bamlss <- describe_prior.BGGM
+
+#' @export
+describe_prior.draws <- describe_prior.BGGM
+
+#' @export
+describe_prior.rvar <- describe_prior.BGGM
