@@ -2,7 +2,7 @@
 #'
 #' This function returns the effective sample size (ESS).
 #'
-#' @param model A `stanreg`, `stanfit`, or `brmsfit` object.
+#' @param model A `stanreg`, `stanfit`, `brmsfit`, `blavaan`, or `MCMCglmm` object.
 #' @param ... Currently not used.
 #' @inheritParams hdi
 #'
@@ -27,6 +27,12 @@ effective_sample <- function(model, ...) {
 }
 
 
+#' @export
+effective_sample.default <- function(model, ...) {
+  stop(insight::format_message(paste0("'effective_sample()' is not yet implemented for objects of class '", class(model)[1], "'.")), call. = FALSE)
+}
+
+
 #' @rdname effective_sample
 #' @export
 effective_sample.brmsfit <- function(model, effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, ...) {
@@ -34,6 +40,62 @@ effective_sample.brmsfit <- function(model, effects = c("fixed", "random", "all"
   effects <- match.arg(effects)
   component <- match.arg(component)
 
+  pars <- insight::find_parameters(
+    model,
+    effects = effects,
+    component = component,
+    parameters = parameters,
+    flatten = TRUE
+  )
+
+  insight::check_if_installed("rstan")
+
+  s <- rstan::summary(model$fit)$summary
+  s <- subset(s, subset = rownames(s) %in% pars)
+
+  data.frame(
+    Parameter = rownames(s),
+    ESS = round(s[, "n_eff"]),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+}
+
+
+#' @rdname effective_sample
+#' @export
+effective_sample.stanreg <- function(model, effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
+  # check arguments
+  effects <- match.arg(effects)
+  component <- match.arg(component)
+
+  pars <-
+    insight::find_parameters(
+      model,
+      effects = effects,
+      component = component,
+      parameters = parameters,
+      flatten = TRUE
+    )
+
+  s <- as.data.frame(summary(model))
+  s <- s[rownames(s) %in% pars, ]
+
+  data.frame(
+    Parameter = rownames(s),
+    ESS = s[["n_eff"]],
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+}
+
+
+#' @export
+effective_sample.stanmvreg <- function(model, effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
+  # check arguments
+  effects <- match.arg(effects)
+  component <- match.arg(component)
+
   pars <- insight::get_parameters(
     model,
     effects = effects,
@@ -41,36 +103,6 @@ effective_sample.brmsfit <- function(model, effects = c("fixed", "random", "all"
     parameters = parameters
   )
 
-  insight::check_if_installed("rstan")
-
-  s <- rstan::summary(model$fit)$summary
-  s <- subset(s, subset = rownames(s) %in% colnames(pars))
-
-  data.frame(
-    Parameter = rownames(s),
-    ESS = round(s[, "n_eff"]),
-    stringsAsFactors = FALSE,
-    row.names = NULL
-  )
-}
-
-
-
-#' @rdname effective_sample
-#' @export
-effective_sample.stanreg <- function(model, effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
-  # check arguments
-  effects <- match.arg(effects)
-  component <- match.arg(component)
-
-  pars <-
-    insight::get_parameters(
-      model,
-      effects = effects,
-      component = component,
-      parameters = parameters
-    )
-
   s <- as.data.frame(summary(model))
   s <- s[rownames(s) %in% colnames(pars), ]
 
@@ -83,7 +115,6 @@ effective_sample.stanreg <- function(model, effects = c("fixed", "random", "all"
 }
 
 
-
 #' @export
 effective_sample.stanfit <- function(model, effects = c("fixed", "random", "all"), parameters = NULL, ...) {
   # check arguments
@@ -110,7 +141,6 @@ effective_sample.stanfit <- function(model, effects = c("fixed", "random", "all"
 }
 
 
-#' @rdname effective_sample
 #' @export
 effective_sample.blavaan <- function(model, parameters = NULL, ...) {
   insight::check_if_installed("blavaan")
@@ -126,7 +156,6 @@ effective_sample.blavaan <- function(model, parameters = NULL, ...) {
 }
 
 
-#' @rdname effective_sample
 #' @export
 effective_sample.MCMCglmm <- function(model, effects = c("fixed", "random", "all"), parameters = NULL, ...) {
   # check arguments
