@@ -2,15 +2,15 @@
 #'
 #' Compute various point-estimates, such as the mean, the median or the MAP, to describe posterior distributions.
 #'
-#' @param centrality The point-estimates (centrality indices) to compute.  Character (vector) or list with one or more of these options: \code{"median"}, \code{"mean"}, \code{"MAP"} or \code{"all"}.
-#' @param dispersion Logical, if \code{TRUE}, computes indices of dispersion related to the estimate(s) (\code{SD} and \code{MAD} for \code{mean} and \code{median}, respectively).
-#' @param threshold For \code{centrality = "trimmed"} (i.e. trimmed mean), indicates the fraction (0 to 0.5) of observations to be trimmed from each end of the vector before the mean is computed.
+#' @param centrality The point-estimates (centrality indices) to compute.  Character (vector) or list with one or more of these options: `"median"`, `"mean"`, `"MAP"` or `"all"`.
+#' @param dispersion Logical, if `TRUE`, computes indices of dispersion related to the estimate(s) (`SD` and `MAD` for `mean` and `median`, respectively).
+#' @param threshold For `centrality = "trimmed"` (i.e. trimmed mean), indicates the fraction (0 to 0.5) of observations to be trimmed from each end of the vector before the mean is computed.
 #' @param ... Additional arguments to be passed to or from methods.
 #' @inheritParams hdi
 #'
-#' @references \href{https://easystats.github.io/bayestestR/articles/indicesEstimationComparison.html}{Vignette In-Depth 1: Comparison of Point-Estimates}
+#' @references Makowski, D., Ben-Shachar, M. S., Chen, S. H. A., and Lüdecke, D. (2019). *Indices of Effect Existence and Significance in the Bayesian Framework*. Frontiers in Psychology 2019;10:2767. \doi{10.3389/fpsyg.2019.02767}
 #'
-#' @note There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/bayestestR.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @examples
 #' library(bayestestR)
@@ -51,18 +51,22 @@
 #' point_estimate(bf, centrality = c("median", "MAP"))
 #' }
 #'
-#' @importFrom stats mad median sd
 #' @export
-point_estimate <- function(x, centrality = "all", dispersion = FALSE, ...) {
+point_estimate <- function(x, ...) {
   UseMethod("point_estimate")
 }
 
 
+#' @export
+point_estimate.default <- function(x, ...) {
+  stop(insight::format_message(paste0("'point_estimate()' is not yet implemented for objects of class '", class(x)[1], "'.")), call. = FALSE)
+}
+
 
 #' @rdname point_estimate
 #' @export
 point_estimate.numeric <- function(x, centrality = "all", dispersion = FALSE, threshold = .1, ...) {
-  centrality <- match.arg(tolower(centrality), c("median", "mean", "map", "trimmed", "all"), several.ok = TRUE)
+  centrality <- match.arg(tolower(centrality), c("median", "mean", "map", "trimmed", "mode", "all"), several.ok = TRUE)
   if ("all" %in% centrality) {
     estimate_list <- c("median", "mean", "map")
   } else {
@@ -100,6 +104,12 @@ point_estimate.numeric <- function(x, centrality = "all", dispersion = FALSE, th
     out$MAP <- as.numeric(map_estimate(x))
   }
 
+  # MODE
+  if ("mode" %in% estimate_list) {
+    out$Mode <- .mode_estimate(x)
+  }
+
+
   out <- out[names(out) != ".temp"]
   attr(out, "data") <- x
   attr(out, "centrality") <- centrality
@@ -109,6 +119,12 @@ point_estimate.numeric <- function(x, centrality = "all", dispersion = FALSE, th
 }
 
 
+.mode_estimate <- function(x) {
+  ux <- unique(x)
+  ux[which.max(tabulate(match(x, ux)))]
+}
+
+
 
 #' @export
 point_estimate.data.frame <- function(x, centrality = "all", dispersion = FALSE, threshold = .1, ...) {
@@ -131,6 +147,15 @@ point_estimate.data.frame <- function(x, centrality = "all", dispersion = FALSE,
 }
 
 
+#' @export
+point_estimate.draws <- function(x, centrality = "all", dispersion = FALSE, threshold = .1, ...) {
+  point_estimate(.posterior_draws_to_df(x), centrality = centrality, dispersion = dispersion, threshold = threshold, ...)
+}
+
+#' @export
+point_estimate.rvar <- point_estimate.draws
+
+
 #' @export
 point_estimate.mcmc <- function(x, centrality = "all", dispersion = FALSE, ...) {
   point_estimate(as.data.frame(x), centrality = centrality, dispersion = dispersion, ...)
@@ -146,14 +171,24 @@ point_estimate.bcplm <- function(x, centrality = "all", dispersion = FALSE, ...)
 point_estimate.bayesQR <- point_estimate.bcplm
 
 
+#' @export
+point_estimate.blrm <- point_estimate.bcplm
+
+
 #' @export
 point_estimate.mcmc.list <- point_estimate.bcplm
 
 
 #' @export
-point_estimate.bamlss <- function(x, centrality = "all", dispersion = FALSE,  component = c("conditional", "location", "all"), ...) {
+point_estimate.BGGM <- point_estimate.bcplm
+
+
+#' @export
+point_estimate.bamlss <- function(x, centrality = "all", dispersion = FALSE, component = c("conditional", "location", "all"), ...) {
   component <- match.arg(component)
-  point_estimate(insight::get_parameters(x, component = component), centrality = centrality, dispersion = dispersion, ...)
+  out <- point_estimate(insight::get_parameters(x, component = component), centrality = centrality, dispersion = dispersion, ...)
+  out <- .add_clean_parameters_attribute(out, x)
+  out
 }
 
 
@@ -169,7 +204,7 @@ point_estimate.emmGrid <- function(x, centrality = "all", dispersion = FALSE, ..
   xdf <- insight::get_parameters(x)
 
   out <- point_estimate(xdf, centrality = centrality, dispersion = dispersion, ...)
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   out
 }
 
@@ -177,31 +212,33 @@ point_estimate.emmGrid <- function(x, centrality = "all", dispersion = FALSE, ..
 point_estimate.emm_list <- point_estimate.emmGrid
 
 
+# Helper ------------------------------------------------------------------
+
+
 
-#' @importFrom insight get_parameters
 #' @keywords internal
 .point_estimate_models <- function(x, effects, component, parameters, centrality = "all", dispersion = FALSE, ...) {
   out <- point_estimate(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), centrality = centrality, dispersion = dispersion, ...)
-  # out$Parameter <- .get_parameter_names(x, effects = effects, component = component, parameters = parameters)
   out
 }
 
 
-#' @importFrom insight get_parameters clean_parameters
 #' @rdname point_estimate
 #' @export
 point_estimate.stanreg <- function(x, centrality = "all", dispersion = FALSE, effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
+  cleaned_parameters <- insight::clean_parameters(x)
 
   out <- .prepare_output(
     point_estimate(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), centrality = centrality, dispersion = dispersion, ...),
-    insight::clean_parameters(x),
+    cleaned_parameters,
     inherits(x, "stanmvreg")
   )
 
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   attr(out, "centrality") <- centrality
+  attr(out, "clean_parameters") <- cleaned_parameters
   class(out) <- unique(c("point_estimate", "see_point_estimate", class(out)))
 
   out
@@ -210,20 +247,25 @@ point_estimate.stanreg <- function(x, centrality = "all", dispersion = FALSE, ef
 #' @export
 point_estimate.stanfit <- point_estimate.stanreg
 
+#' @export
+point_estimate.blavaan <- point_estimate.stanreg
+
 
 #' @rdname point_estimate
 #' @export
 point_estimate.brmsfit <- function(x, centrality = "all", dispersion = FALSE, effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
+  cleaned_parameters <- insight::clean_parameters(x)
 
   out <- .prepare_output(
     point_estimate(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), centrality = centrality, dispersion = dispersion, ...),
-    insight::clean_parameters(x)
+    cleaned_parameters
   )
 
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   attr(out, "centrality") <- centrality
+  attr(out, "clean_parameters") <- cleaned_parameters
   class(out) <- unique(c("point_estimate", "see_point_estimate", class(out)))
 
   out
@@ -245,6 +287,7 @@ point_estimate.sim.merMod <- function(x, centrality = "all", dispersion = FALSE,
   )
   attr(out, "data") <- insight::get_parameters(x, effects = effects, parameters = parameters)
   attr(out, "centrality") <- centrality
+  out <- .add_clean_parameters_attribute(out, x)
   class(out) <- unique(c("point_estimate", "see_point_estimate", class(out)))
 
   out
@@ -276,9 +319,25 @@ point_estimate.sim <- function(x, centrality = "all", dispersion = FALSE, parame
 #' @export
 point_estimate.BFBayesFactor <- function(x, centrality = "all", dispersion = FALSE, ...) {
   out <- point_estimate(insight::get_parameters(x), centrality = centrality, dispersion = dispersion, ...)
-  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
   attr(out, "centrality") <- centrality
   class(out) <- unique(c("point_estimate", "see_point_estimate", class(out)))
 
   out
 }
+
+
+#' @export
+point_estimate.matrix <- function(x, ...) {
+  point_estimate(as.data.frame(x), ...)
+}
+
+
+#' @export
+point_estimate.get_predicted <- function(x, ...) {
+  if ("iterations" %in% names(attributes(x))) {
+    point_estimate(as.data.frame(t(attributes(x)$iterations)), ...)
+  } else {
+    as.numeric(x)
+  }
+}
