@@ -1,43 +1,45 @@
 #' Compute Support Intervals
 #'
 #' A support interval contains only the values of the parameter that predict the observed data better
-#' than average, by some degree \emph{k}; these are values of the parameter that are associated with an
-#' updating factor greater or equal than \emph{k}. From the perspective of the Savage-Dickey Bayes factor, testing
+#' than average, by some degree *k*; these are values of the parameter that are associated with an
+#' updating factor greater or equal than *k*. From the perspective of the Savage-Dickey Bayes factor, testing
 #' against a point null hypothesis for any value within the support interval will yield a Bayes factor smaller
-#' than \emph{1/k}.
+#' than *1/k*.
 #' \cr \cr
 #' \strong{For more info, in particular on specifying correct priors for factors with more than 2 levels,
-#' see \href{https://easystats.github.io/bayestestR/articles/bayes_factors.html}{the Bayes factors vignette}.}
+#' see [the Bayes factors vignette](https://easystats.github.io/bayestestR/articles/bayes_factors.html).}
 #'
 #' @param BF The amount of support required to be included in the support interval.
 #' @inheritParams bayesfactor_parameters
 #' @inheritParams hdi
+#' @inherit hdi seealso
+#' @family ci
 #'
 #' @details This method is used to compute support intervals based on prior and posterior distributions.
 #' For the computation of support intervals, the model priors must be proper priors (at the very least
-#' they should be \emph{not flat}, and it is preferable that they be \emph{informative} - note
-#' that by default, \code{brms::brm()} uses flat priors for fixed-effects; see example below).
+#' they should be *not flat*, and it is preferable that they be *informative* - note
+#' that by default, `brms::brm()` uses flat priors for fixed-effects; see example below).
 #'
-#' \subsection{Choosing a value of \code{BF}}{
-#' The choice of \code{BF} (the level of support) depends on what we want our interval to represent:
+#' \subsection{Choosing a value of `BF`}{
+#' The choice of `BF` (the level of support) depends on what we want our interval to represent:
 #' \itemize{
-#'   \item A \code{BF} = 1 contains values whose credibility is not decreased by observing the data.
-#'   \item A \code{BF} > 1 contains values who recived more impressive support from the data.
-#'   \item A \code{BF} < 1 contains values whose credibility has \emph{not} been impressively decreased by observing the data.
-#'   Testing against values outside this interval will produce a Bayes factor larger than 1/\code{BF} in support of
+#'   \item A `BF` = 1 contains values whose credibility is not decreased by observing the data.
+#'   \item A `BF` > 1 contains values who received more impressive support from the data.
+#'   \item A `BF` < 1 contains values whose credibility has *not* been impressively decreased by observing the data.
+#'   Testing against values outside this interval will produce a Bayes factor larger than 1/`BF` in support of
 #'   the alternative. E.g., if an SI (BF = 1/3) excludes 0, the Bayes factor against the point-null will be larger than 3.
 #' }
 #' }
 #'
-#' @inheritSection bayesfactor_parameters Setting the correct \code{prior}
+#' @inheritSection bayesfactor_parameters Setting the correct `prior`
 #'
-#' @note There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/bayestestR.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @return
 #' A data frame containing the lower and upper bounds of the SI.
 #' \cr
 #' Note that if the level of requested support is higher than observed in the data, the
-#' interval will be \code{[NA,NA]}.
+#' interval will be `[NA,NA]`.
 #'
 #' @examples
 #' library(bayestestR)
@@ -50,7 +52,7 @@
 #' # rstanarm models
 #' # ---------------
 #' library(rstanarm)
-#' contrasts(sleep$group) <- contr.bayes # see vingette
+#' contrasts(sleep$group) <- contr.equalprior_pairs # see vingette
 #' stan_model <- stan_lmer(extra ~ group + (1 | ID), data = sleep)
 #' si(stan_model)
 #' si(stan_model, BF = 3)
@@ -64,7 +66,7 @@
 #' # brms models
 #' # -----------
 #' library(brms)
-#' contrasts(sleep$group) <- contr.bayes # see vingette
+#' contrasts(sleep$group) <- contr.equalprior_pairs # see vingette
 #' my_custom_priors <-
 #'   set_prior("student_t(3, 0, 1)", class = "b") +
 #'   set_prior("student_t(3, 0, 1)", class = "sd", group = "ID")
@@ -89,11 +91,11 @@ si.numeric <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
   if (is.null(prior)) {
     prior <- posterior
     if (verbose) {
-      warning(
-        "Prior not specified! ",
-        "Please specify a prior (in the form 'prior = distribution_normal(1000, 0, 1)')",
-        " to get meaningful results."
-      )
+      warning(insight::format_message(
+        "Prior not specified!",
+        "Support intervals ('si') can only be computed for Bayesian models with proper priors.",
+        "Please specify priors (with column order matching 'posterior')."
+      ), call. = FALSE)
     }
   }
   prior <- data.frame(X = prior)
@@ -108,7 +110,6 @@ si.numeric <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
   out
 }
 
-#' @importFrom insight clean_parameters
 #' @rdname si
 #' @export
 si.stanreg <- function(posterior, prior = NULL,
@@ -135,7 +136,8 @@ si.stanreg <- function(posterior, prior = NULL,
 
   out <- .prepare_output(temp, cleaned_parameters, inherits(posterior, "stanmvreg"))
 
-  attr(out, "object_name") <- .safe_deparse(substitute(posterior))
+  attr(out, "ci_method") <- "SI"
+  attr(out, "object_name") <- insight::safe_deparse(substitute(posterior))
   class(out) <- class(temp)
   attr(out, "plot_data") <- attr(temp, "plot_data")
 
@@ -147,6 +149,10 @@ si.stanreg <- function(posterior, prior = NULL,
 #' @export
 si.brmsfit <- si.stanreg
 
+#' @rdname si
+#' @export
+si.blavaan <- si.stanreg
+
 
 #' @rdname si
 #' @export
@@ -162,7 +168,8 @@ si.emmGrid <- function(posterior, prior = NULL,
     BF = BF, verbose = verbose, ...
   )
 
-  attr(out, "object_name") <- .safe_deparse(substitute(posterior))
+  attr(out, "ci_method") <- "SI"
+  attr(out, "object_name") <- insight::safe_deparse(substitute(posterior))
   out
 }
 
@@ -170,29 +177,70 @@ si.emmGrid <- function(posterior, prior = NULL,
 si.emm_list <- si.emmGrid
 
 
+#' @export
+si.stanfit <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, effects = c("fixed", "random", "all"), ...) {
+  out <- si(insight::get_parameters(posterior, effects = effects),
+    prior = prior, BF = BF, verbose = verbose
+  )
+  attr(out, "object_name") <- insight::safe_deparse(substitute(posterior))
+  out
+}
+
+#' @export
+si.get_predicted <- function(posterior, ...) {
+  out <- si(as.data.frame(t(posterior)), ...)
+  attr(out, "object_name") <- insight::safe_deparse(substitute(posterior))
+  out
+}
+
+
 #' @rdname si
 #' @export
 si.data.frame <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
-  if (length(BF) > 1) {
-    SIs <- lapply(BF, function(i) {
-      si(posterior, prior = prior, BF = i, verbose = verbose, ...)
-    })
-    out <- do.call(rbind, SIs)
-
-    attr(out, "plot_data") <- attr(SIs[[1]], "plot_data")
-    class(out) <- unique(c("bayestestR_si", "bayestestR_ci", class(out)))
-    return(out)
-  }
-
   if (is.null(prior)) {
     prior <- posterior
+    warning(insight::format_message(
+      "Prior not specified!",
+      "Support intervals ('si') can only be computed for Bayesian models with proper priors.",
+      "Please specify priors (with column order matching 'posterior')."
+    ), call. = FALSE)
+  }
+
+  if (verbose && (nrow(posterior) < 4e4 || nrow(prior) < 4e4)) {
     warning(
-      "Prior not specified! ",
-      "Please specify priors (with column order matching 'posterior')",
-      " to get meaningful results."
+      "Support intervals might not be precise.\n",
+      "For precise support intervals, sampling at least 40,000 posterior samples is recommended.",
+      call. = FALSE
     )
   }
 
+  out <- lapply(BF, function(BFi) {
+    .si.data.frame(posterior, prior, BFi)
+  })
+  out <- do.call(rbind, out)
+
+  attr(out, "ci_method") <- "SI"
+  attr(out, "ci") <- BF
+  attr(out, "plot_data") <- .make_BF_plot_data(posterior, prior, 0, 0, ...)$plot_data
+  class(out) <- unique(c("bayestestR_si", "see_si", "bayestestR_ci", "see_ci", class(out)))
+
+  out
+}
+
+
+#' @export
+si.draws <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...) {
+  si(.posterior_draws_to_df(posterior), prior = prior, BF = BF, verbose = verbose, ...)
+}
+
+#' @export
+si.rvar <- si.draws
+
+
+
+# Helper ------------------------------------------------------------------
+
+.si.data.frame <- function(posterior, prior, BF, ...) {
   sis <- matrix(NA, nrow = ncol(posterior), ncol = 2)
   for (par in seq_along(posterior)) {
     sis[par, ] <- .si(posterior[[par]],
@@ -208,25 +256,13 @@ si.data.frame <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, ...)
     CI_high = sis[, 2],
     stringsAsFactors = FALSE
   )
-  class(out) <- unique(c("bayestestR_si", "see_si", "bayestestR_ci", "see_ci", class(out)))
-  attr(out, "plot_data") <- .make_BF_plot_data(posterior, prior, 0, 0, ...)$plot_data
-
-  out
 }
 
 
-#' @export
-si.stanfit <- function(posterior, prior = NULL, BF = 1, verbose = TRUE, effects = c("fixed", "random", "all"), ...) {
-  si(insight::get_parameters(posterior, effects = effects))
-}
 
-
-#' @importFrom stats median mad na.omit
 #' @keywords internal
 .si <- function(posterior, prior, BF = 1, extend_scale = 0.05, precision = 2^8, ...) {
-  if (!requireNamespace("logspline")) {
-    stop("Package \"logspline\" needed for this function to work. Please install it.")
-  }
+  insight::check_if_installed("logspline")
 
   if (isTRUE(all.equal(prior, posterior))) {
     return(c(NA, NA))
