@@ -1,8 +1,8 @@
-if (require("rstanarm") && require("brms") && require("insight")) {
+if (requiet("rstanarm") && requiet("brms") && requiet("insight")) {
   test_that("effective_sample", {
     brms_1 <- insight::download_model("brms_1")
     res <- effective_sample(brms_1)
-    testthat::expect_equal(
+    expect_equal(
       res,
       data.frame(
         Parameter = c("b_Intercept", "b_wt", "b_cyl"),
@@ -13,7 +13,7 @@ if (require("rstanarm") && require("brms") && require("insight")) {
 
     brms_null_1 <- insight::download_model("brms_null_1")
     res <- effective_sample(brms_null_1)
-    testthat::expect_equal(
+    expect_equal(
       res,
       data.frame(
         Parameter = c("b_Intercept"),
@@ -24,7 +24,7 @@ if (require("rstanarm") && require("brms") && require("insight")) {
 
     brms_null_2 <- insight::download_model("brms_null_2")
     res <- effective_sample(brms_null_2)
-    testthat::expect_equal(
+    expect_equal(
       res,
       data.frame(
         Parameter = c("b_Intercept"),
