@@ -1,6 +1,6 @@
 .runThisTest <- Sys.getenv("RunAllbayestestRTests") == "yes"
 if (.runThisTest) {
-  if (require("rstanarm") && suppressPackageStartupMessages(require("bayestestR", quietly = TRUE)) && require("httr") && require("insight")) {
+  if (requiet("rstanarm") && requiet("bayestestR") && requiet("httr") && requiet("insight")) {
     test_that("rstanarm", {
       skip_on_cran()
 
@@ -27,7 +27,7 @@ if (.runThisTest) {
       expect_equal(rope_range(model, verbose = FALSE)[1], -0.043, tolerance = 0.1)
 
       model <- insight::download_model("stanreg_gam_1")
-      params <- describe_posterior(model, centrality = "all", test = "all", dispersion = TRUE)
+      expect_warning(params <- describe_posterior(model, centrality = "all", test = "all", dispersion = TRUE))
       expect_equal(c(nrow(params), ncol(params)), c(4, 22))
 
       expect_s3_class(hdi(model), "data.frame")
@@ -48,7 +48,7 @@ if (.runThisTest) {
       set.seed(333)
       model <- insight::download_model("stanreg_glm_3")
 
-      out <- describe_posterior(model, effects = "all", components = "all", centrality = "mean")
+      out <- describe_posterior(model, effects = "all", component = "all", centrality = "mean")
       s <- summary(model)
       expect_identical(colnames(out), c(
         "Parameter", "Mean", "CI", "CI_low", "CI_high", "pd", "ROPE_CI",
@@ -64,7 +64,7 @@ if (.runThisTest) {
       set.seed(333)
       model <- insight::download_model("stanreg_merMod_3")
 
-      out <- describe_posterior(model, effects = "all", components = "all", centrality = "mean")
+      out <- describe_posterior(model, effects = "all", component = "all", centrality = "mean")
       s <- summary(model)
       expect_identical(colnames(out), c(
         "Parameter", "Effects", "Mean", "CI", "CI_low", "CI_high",
@@ -81,7 +81,7 @@ if (.runThisTest) {
       set.seed(333)
       model <- insight::download_model("stanmvreg_1")
 
-      out <- describe_posterior(model, effects = "fixed", components = "all", centrality = "mean", test = NULL)
+      out <- describe_posterior(model, effects = "fixed", component = "all", centrality = "mean", test = NULL)
       s <- summary(model)
       expect_identical(colnames(out), c(
         "Parameter", "Response", "Mean", "CI", "CI_low", "CI_high",
@@ -98,7 +98,7 @@ if (.runThisTest) {
       set.seed(333)
       model <- insight::download_model("stanmvreg_1")
 
-      out <- describe_posterior(model, effects = "fixed", components = "all", centrality = "mean", test = NULL, priors = TRUE)
+      out <- describe_posterior(model, effects = "fixed", component = "all", centrality = "mean", test = NULL, priors = TRUE)
       expect_identical(colnames(out), c(
         "Parameter", "Response", "Mean", "CI", "CI_low", "CI_high",
         "Rhat", "ESS", "Prior_Distribution", "Prior_Location",
